=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2006-04-19 07:16:05 +0000
+++ bzrlib/diff.py	2006-04-20 01:29:04 +0000
@@ -313,7 +313,7 @@
 
 def _raise_if_doubly_unversioned(specific_files, old_tree, new_tree):
     """Complain if paths are not versioned in either tree."""
-    if len(specific_files) == 0:
+    if not specific_files:
         return
     old_unversioned = old_tree.filter_unversioned_files(specific_files)
     new_unversioned = new_tree.filter_unversioned_files(specific_files)

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-04-19 07:16:05 +0000
+++ bzrlib/errors.py	2006-04-20 01:29:04 +0000
@@ -68,6 +68,10 @@
 # TODO: Convert all the other error classes here to BzrNewError, and eliminate
 # the old one.
 
+# TODO: The pattern (from hct) of using classes docstrings as message
+# templates is cute but maybe not such a great idea - perhaps should have a
+# separate static message_template.
+
 
 class BzrError(StandardError):
     def __str__(self):
@@ -172,6 +176,8 @@
     """Commit refused because there are unknowns in the tree."""
 
 
+# XXX: Should be unified with TransportError; they seem to represent the
+# same thing
 class PathError(BzrNewError):
     """Generic path error: %(path)r%(extra)s)"""
 

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2006-03-28 20:53:12 +0000
+++ bzrlib/lockdir.py	2006-04-20 01:29:04 +0000
@@ -109,9 +109,11 @@
         LockError,
         LockNotHeld,
         NoSuchFile,
+        PathError,
         ResourceBusy,
         UnlockableTransport,
         )
+from bzrlib.trace import mutter
 from bzrlib.transport import Transport
 from bzrlib.osutils import rand_chars
 from bzrlib.rio import RioWriter, read_stanza, Stanza
@@ -201,11 +203,9 @@
             self.transport.rename(tmpname, self._held_dir)
             self._lock_held = True
             self.confirm()
-            return
-        except (DirectoryNotEmpty, FileExists, ResourceBusy), e:
-            pass
-        # fall through to here on contention
-        raise LockContention(self)
+        except (PathError, DirectoryNotEmpty, FileExists, ResourceBusy), e:
+            mutter("contention on %r: %s", self, e)
+            raise LockContention(self)
 
     def unlock(self):
         """Release a held lock

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-04-12 04:45:32 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-04-20 01:29:04 +0000
@@ -781,9 +781,9 @@
         self.assertEqual([u'a', u'c', u'c2'], sorted_list('.'))
         self.assertEqual([u'e'], sorted_list(u'c'))
 
-        self.assertListRaises(NoSuchFile, t.list_dir, 'q')
-        self.assertListRaises(NoSuchFile, t.list_dir, 'c/f')
-        self.assertListRaises(NoSuchFile, t.list_dir, 'a')
+        self.assertListRaises(PathError, t.list_dir, 'q')
+        self.assertListRaises(PathError, t.list_dir, 'c/f')
+        self.assertListRaises(PathError, t.list_dir, 'a')
 
     def test_clone(self):
         # TODO: Test that clone moves up and down the filesystem

=== modified file 'bzrlib/transport/sftp.py'
--- bzrlib/transport/sftp.py	2006-04-06 05:28:00 +0000
+++ bzrlib/transport/sftp.py	2006-04-20 01:29:04 +0000
@@ -1,4 +1,5 @@
-# Copyright (C) 2005 Robey Pointer <robey@lag.net>, Canonical Ltd
+# Copyright (C) 2005 Robey Pointer <robey@lag.net>
+# Copyright (C) 2005, 2006 Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +35,9 @@
                            FileExists, 
                            TransportNotPossible, NoSuchFile, PathNotChild,
                            TransportError,
-                           LockError, ParamikoNotPresent
+                           LockError, 
+                           PathError,
+                           ParamikoNotPresent,
                            )
 from bzrlib.osutils import pathjoin, fancy_rename
 from bzrlib.trace import mutter, warning, error
@@ -470,7 +473,8 @@
             self._translate_io_exception(e, path, ': unable to mkdir',
                 failure_exc=FileExists)
 
-    def _translate_io_exception(self, e, path, more_info='', failure_exc=NoSuchFile):
+    def _translate_io_exception(self, e, path, more_info='', 
+                                failure_exc=PathError):
         """Translate a paramiko or IOError into a friendlier exception.
 
         :param e: The original exception
@@ -480,8 +484,8 @@
         :param failure_exc: Paramiko has the super fun ability to raise completely
                            opaque errors that just set "e.args = ('Failure',)" with
                            no more information.
-                           This sometimes means FileExists, but it also sometimes
-                           means NoSuchFile
+                           If this parameter is set, it defines the exception 
+                           to raise in these cases.
         """
         # paramiko seems to generate detailless errors.
         self._translate_error(e, path, raise_generic=False)

